@@ -1,5 +1,5 @@
 package Etcd::Node;
-$Etcd::Node::VERSION = '0.002';
+$Etcd::Node::VERSION = '0.003';
 use namespace::sweep;
 
 use Moo;
@@ -23,7 +23,7 @@ has created_index  => ( is => 'ro', isa => Int, init_arg => 'createdIndex'  );
 has modified_index => ( is => 'ro', isa => Int, init_arg => 'modifiedIndex' );
 has ttl            => ( is => 'ro', isa => Int );
 has expiration     => ( is => 'ro', isa => $ISO8601 );
-has dir            => ( is => 'ro', isa => Bool );
+has dir            => ( is => 'ro', isa => Bool, coerce => sub { !! $_[0] } );
 
 has nodes => (
     is => 'ro',
@@ -45,7 +45,7 @@ Etcd::Node - key space node representation
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
